@@ -316,9 +316,9 @@ tv_button_release_event(GtkTreeView *tv, GdkEventButton *ev, ChoiceParams *cp)
 
 				gtk_tree_model_get(tm, &itr, 0, &str, -1);
 				if (g_strcmp0(str, hildon_button_get_value(HILDON_BUTTON(cp->choice_details)))) {
-					g_signal_handlers_block_matched(G_OBJECT(cp->choice_details), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, choice_details_changed, cp);
+//					g_signal_handlers_block_matched(G_OBJECT(cp->choice_details), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, choice_details_changed, cp);
 					g_object_set(G_OBJECT(cp->choice_details), "value", str, NULL);
-					g_signal_handlers_unblock_matched(G_OBJECT(cp->choice_details), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, choice_details_changed, cp);
+//					g_signal_handlers_unblock_matched(G_OBJECT(cp->choice_details), G_SIGNAL_MATCH_FUNC, 0, 0, NULL, choice_details_changed, cp);
 				}
 				g_free(str);
 				gtk_tree_selection_select_iter(ts, &itr);
